@@ -20,7 +20,7 @@ class CheckBoxGroupArgs(CommonParameterWidgetArgs):
 
 class CheckBoxGroup(CommonParameterWidget):
     SET_DEFAULT_ON_INIT = True
-    HIDE_DEFAULT_WIDGET = True
+    HIDE_DEFAULT_VALUE_WIDGET = True
 
     _WidgetArgsClass = CheckBoxGroupArgs
 
